# Clear memory and set random seed ---------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
set.seed(123)   # Makes it reproducable also if random number generators are used
#-------------------------------------------------------------------------------

# Import data ------------------------------------------------------------------
# Change the path below to where you have stored the data files
setwd("~/Box Sync/_PDF/My Supplements/Ruhnau12")

dlong <- read.table('mc__a_ah10l020_ERP_90-120.txt', header = TRUE, sep = ' ')
# ------------------------------------------------------------------------------

# select only M1M2 and drop the chan col
tmp = dlong[dlong$chan=="M1M2",-2]
# change col name ampl to M
names(tmp)[names(tmp)=="ampl"] = "M"
# From long to wide format -----------------------------------------------------
D_M1M2 <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

tmp = dlong[dlong$chan=="FzF3F4CzC3C4",-2]
names(tmp)[names(tmp)=="ampl"] = "F"
# From long to wide format -----------------------------------------------------
D_Fchan <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

D = merge(D_Fchan, D_M1M2, by = "vp")

# sa - standard ascending
# sd - standard descending
# da - deviant ascending
# dd - deviant descending
# ca - control ascending (oder cascadic)
# cd - control/cascading descending
# ra - random ascending
# rd - random descending
# ==
# cba - cascading before ascending
# caa - cascading after ascending
# cbd - cascading before descending
# cad - cascading after descending

source('BF_U.R')

# frontal
N1dev = (D$F.da+D$F.dd)/2
N1std = (D$F.sa+D$F.sd)/2
N1cas = (D$F.ca+D$F.cd)/2
N1rnd = (D$F.ra+D$F.rd)/2
N1casmrnd = N1cas - N1rnd

mN1dev = mean(N1dev)
mN1std = mean(N1std)
mN1cas = mean(N1cas)
mN1rnd = mean(N1rnd)


#jpeg(file="Mean amps at N1 interval.jpg", res = 300, width = 3000, height = 1400)
barplot(c(mN1dev, mN1std, mN1cas, mN1rnd), names.arg = c('dev', 'std', 'cas', 'rnd'))
#invisible(dev.off())

# rnd should have the biggest N1 (UL) 
mN1devmrnd = mN1dev - mN1rnd
# Thus, devmrnd should give a positive number (bc rnd has a bigger N1)
# correct!

# cas minus rnd should give a positive number (bc rnd has a bigger N1)
mN1casmrnd = mN1cas - mN1rnd
# correct!

# Define BF
# ---------
LL = 0 
UL = round(mN1devmrnd, digits = 3)
meanobtained = mN1casmrnd
semobtained = sd(N1casmrnd)/sqrt(nrow(D))
dfobtained = nrow(D)-1
# dfobtained = 10000, this assumes normal distribution of the data
# the BF = 125, checked with Dienes' online BF
BF_U(LL, UL, meanobtained, semobtained, dfobtained)
# Results:
#  BF10 =  40.26 
#  BF01 =  0.02 



