# Clear memory and set random seed ---------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
set.seed(123)   # Makes it reproducable also if random number generators are used
#-------------------------------------------------------------------------------

# Import data ------------------------------------------------------------------
# Change the path below to where you have stored the data files
setwd("~/Exp_CascadeMMN/BF_Ruhnau_2012")

dlong <- read.table('mc__a_ah10l020_ERP_140-190.txt', header = TRUE, sep = ' ')
# ------------------------------------------------------------------------------

# select only M1M2 and drop the chan col
tmp = dlong[dlong$chan=="M1M2",-2]
# change col name ampl to M
names(tmp)[names(tmp)=="ampl"] = "M"
# From long to wide format -----------------------------------------------------
D_M1M2 <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

# select only frontal and drop the chan col
tmp = dlong[dlong$chan=="FzF3F4CzC3C4",-2]
names(tmp)[names(tmp)=="ampl"] = "F"
# From long to wide format -----------------------------------------------------
D_Fchan <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

D = merge(D_Fchan, D_M1M2, by = "vp")

# sa - standard ascending
# sd - standard descending
# da - deviant ascending
# dd - deviant descending
# ca - control ascending (oder cascadic)
# cd - control/cascading descending
# ra - random ascending
# rd - random descending
# ==
# cba - cascading before ascending
# caa - cascading after ascending
# cbd - cascading before descending
# cad - cascading after descending

source('BF_U.R')

# frontal
# MMN contains mean amps for the MMN range (not difference scores)
MMNdev = (D$F.da+D$F.dd)/2
MMNstd = (D$F.sa+D$F.sd)/2
MMNcas = (D$F.ca+D$F.cd)/2
MMNrnd = (D$F.ra+D$F.rd)/2
MMNdevmstd = MMNdev - MMNstd
MMNdevmcas = MMNdev - MMNcas
MMNcasmrnd = MMNcas - MMNrnd

mMMNdev = mean(MMNdev)
mMMNstd = mean(MMNstd)
mMMNcas = mean(MMNcas)
mMMNrnd = mean(MMNrnd)

#jpeg(file="Mean amps at MMN interval.jpg", res = 300, width = 3000, height = 1400)
barplot(c(mMMNdev, mMMNstd, mMMNcas, mMMNrnd), names.arg = c('dev', 'std', 'cas', 'rnd'))
#invisible(dev.off())

# The MMNdev should have the most negative number and the std the most positive.
# rnd and cas should fall in between.
# Because rnd should be confounded by the N1, the rnd should be somewhat more negative than the cas.
# Therefore, cas minus rnd should give a positive number (because rnd contains larger N1)
mMMNdevmstd = mean(MMNdevmstd)
mMMNdevmcas = mean(MMNdevmcas)
mMMNdevmrnd = mean(MMNdev) - mean(MMNrnd)
mMMNcasmrnd = mean(MMNcasmrnd)
t.test(MMNcasmrnd)

# The devmstd is the typical oddball MMN
# It sounds reasonable to use this as the UL, ie the difference bn cas and rnd
# is zero or does it differ.
# run BF with LL defined by 0 and UL defined by devmstd
# flip polarity to work with positive numbers (sigh)
LL = 0 
UL = round(-mMMNdevmstd, digits = 3)
meanobtained = mMMNcasmrnd
semobtained = sd(MMNcasmrnd)/sqrt(nrow(D))
dfobtained = nrow(D)-1
BF_U(LL, UL, meanobtained, semobtained, dfobtained)
# Results:
#  BF10 =  0.46 
#  BF01 =  2.17 

t.test(MMNcasmrnd)

# Theoretically, the oddball MMN (dev minus std) may be totally inflated
# because the std underestimates the N1 confound. If so, the oddball MMN
# overestimates the genuine MMN and would be larger than it should be.
# With a larger UL, the evidence is more likely to support the null.
# If one does not want to bias the analysis towards the null hypothesis,
# it would be preferable to assume that the cascade-corrected MMN is the ideal
# measurement of the genuine MMN and to use the cascade-corrected MMN as the UL.
LL = 0 
mMMNdevmcas = mean(mMMNdev - mMMNcas) 
UL = round(-mMMNdevmcas, digits = 3)
meanobtained = mMMNcasmrnd
semobtained = sd(MMNcasmrnd)/sqrt(nrow(D))
dfobtained = nrow(D)-1
BF_U(LL, UL, meanobtained, semobtained, dfobtained)
# Results:
#   BF10 =  0.47 
#   BF01 =  2.13 
# Makes no difference in practice.

# Two-tailed analysis:
LL = round(mMMNdevmstd, digits = 3) 
UL = round(-mMMNdevmstd, digits = 3)
meanobtained = mMMNcasmrnd
semobtained = sd(MMNcasmrnd)/sqrt(nrow(D))
dfobtained = nrow(D)-1
BF_U(LL, UL, meanobtained, semobtained, dfobtained)

