# Clear memory and set random seed ---------------------------------------------
rm(list = ls()) # clear memory
graphics.off()  # clear all plots
cat("\014")     # clear console (same as Ctrl-L in console)
set.seed(123)   # Makes it reproducable also if random number generators are used
#-------------------------------------------------------------------------------

# Import data ------------------------------------------------------------------
# Change the path below to where you have stored the data files
setwd("~/Box Sync/_PDF/My Supplements/Ruhnau12")

dlong <- read.table('mc__a_ah10l020_ERP_90-120.txt', header = TRUE, sep = ' ')
# ------------------------------------------------------------------------------


tmp = dlong[dlong$chan=="M1M2",-2]
names(tmp)[names(tmp)=="ampl"] = "M"
# From long to wide format -----------------------------------------------------
D_M1M2 <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

tmp = dlong[dlong$chan=="FzF3F4CzC3C4",-2]
names(tmp)[names(tmp)=="ampl"] = "F"
# From long to wide format -----------------------------------------------------
D_Fchan <- reshape(tmp, idvar = "vp", timevar = "con", direction = "wide")

D = merge(D_Fchan, D_M1M2, by = "vp")

# sa - standard ascending
# sd - standard descending
# da - deviant ascending
# dd - deviant descending
# ca - control ascending (oder cascadic)
# cd - control/cascading descending
# ra - random ascending
# rd - random descending
# ==
# cba - cascading before ascending
# caa - cascading after ascending
# cbd - cascading before descending
# cad - cascading after descending

D$F_N1_dev = ((D$F.da+D$F.dd)-(D$F.sa+D$F.sd))/2
D$F_N1_cas = ((D$F.ca+D$F.cd)-(D$F.sa+D$F.sd))/2
D$F_N1_rnd = ((D$F.ra+D$F.rd)-(D$F.sa+D$F.sd))/2

# Run this to get only descending deviant
# ================================================
D$F_N1_dev = D$F.dd-D$F.sd
D$F_N1_cas = D$F.cd-D$F.sd
D$F_N1_rnd = D$F.rd-D$F.sd


t_dev = t.test(D$F_N1_dev)
t_dev$statistic^2

t_cas = t.test(D$F_N1_cas)
t_cas$statistic^2

t_rnd = t.test(D$F_N1_rnd)
t_rnd$statistic^2

t_rnd_dev = t.test(D$F_N1_rnd - D$F_N1_dev)
t_rnd_dev$statistic^2

t_rnd_cas = t.test(D$F_N1_rnd - D$F_N1_cas)
t_rnd_cas$statistic^2

t_dev_cas = t.test(D$F_N1_dev - D$F_N1_cas)
t_dev_cas$statistic^2

# 1st approach:
# ============
# The N1 to cascade is the same as that for the oddball deviant
# Limit is set by random
D$F_N1_cas_dev = D$F_N1_cas - D$F_N1_dev
t_cas_dev = t.test(D$F_N1_cas_dev)
t_cas_dev$statistic^2
# CI = [-0.486, 0.246]
boxplot(D$F_N1_cas_dev)
D$all = 1
p = ggplot(D, aes(x = all,y = F_N1_cas_dev)) + geom_boxplot() + geom_jitter()
p

F_N1_cas_dev_mean = mean(D$F_N1_cas_dev, na.rm = T)
F_N1_cas_dev_sem = sd(D$F_N1_cas_dev)/sqrt(length(D$F_N1_cas_dev))
F_N1_rnd_dev_mean = mean(D$F_N1_rnd - D$F_N1_dev, na.rm = T)
# Run Dienes BF
# Uniform
# mean (cas-dev) = -0.1199
# sem (cas-dev) = 0.1719
# mean (rnd-dev) = -0.8295
# For Dienes, use positive scores
# sample sem  = 0.1719
# sample mean = 0.1199
# lower bound = 0
# upper bound = 0.8295
# ==> BF = 0.50.

# Only for descending deviants
# sample sem  = 0.2347
# sample mean = 0.1102
# lower bound = 0
# upper bound = 1.1247
# ==> BF = 0.40.



# 2nd approach:
# ============
# The purpose is to show that the N1 to the cascade is smaller than
# that to the random (with dev as limit).
D$F_N1_cas_rnd = D$F_N1_cas - D$F_N1_rnd
t_cas_rnd = t.test(D$F_N1_cas_rnd)
t_cas_rnd$statistic^2
# CI = [0.258, 1.161]
boxplot(D$F_N1_cas_rnd)
D$all = 1
p = ggplot(D, aes(x = all,y = F_N1_cas_rnd)) + geom_boxplot() + geom_jitter()
p

F_N1_cas_rnd_mean = mean(D$F_N1_cas_rnd, na.rm = T)
F_N1_cas_rnd_sem = sd(D$F_N1_cas_rnd)/sqrt(length(D$F_N1_cas_rnd))
F_N1_rnd_dev_mean = mean(D$F_N1_rnd - D$F_N1_dev, na.rm = T)

# Run Dienes BF
# Uniform
# mean (cas-rnd) = 0.7096
# sem (cas-rnd) = 0.2118
# mean (rnd-dev) = -0.8295
# For Dienes, use positive scores
# sample sem  = 0.2118
# sample mean = 0.7096
# lower bound = 0
# upper bound = .8295
# ==> BF10 = 125.16.

# Only descending deviants
# sample sem  = 0.2070
# sample mean = 1.0144
# lower bound = 0
# upper bound = 1.1247
# ==> BF10 = 53205  !!!

